@@ -1,9 +1,10 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+  under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,13 +22,16 @@
 #include <QPrintPreviewDialog>
 #include "pimcommon_export.h"
 
-namespace PimCommon
-{
+namespace PimCommon {
+/**
+ * @brief The KPimPrintPreviewDialog class
+ * @author Laurent Montel <montel@kde.org>
+ */
 class PIMCOMMON_EXPORT KPimPrintPreviewDialog : public QPrintPreviewDialog
 {
 public:
     explicit KPimPrintPreviewDialog(QWidget *parent = nullptr);
-    explicit KPimPrintPreviewDialog(QPrinter *printer, QWidget *parent = 0);
+    explicit KPimPrintPreviewDialog(QPrinter *printer, QWidget *parent = nullptr);
     ~KPimPrintPreviewDialog();
 private:
     void readConfig();
